
==========================
Leonardo leonardo-3d-viewer
==========================

Extra media type for handling 3D models and related widgets.

.. contents::
    :local:

Installation
------------

.. code-block:: bash

    pip install leonardo-3d-viewer

Read More
=========

* https://github.com/django-leonardo/django-leonardo
